# August 31, 2021

**Date:** August 31, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-08-31/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

**[YouTube link](https://youtu.be/WQ43ywKDfg8)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Rollin** JupyterHub + HPC meeting tomorrow [agenda](https://hackmd.io/r4AuJjSpSoeTw_Br8dgMRA), invite/link on the [community calendar](https://discourse.jupyter.org/t/jupyter-community-calendar/2485)
* **Rollin+Rick** Jupyter Security Meetings, biweekly (Fridays, 9:00 AM PDT)
    * Next call Sep 10
    * Trusted CI Jupyter security docs review
* Mike: Translations for JupyterLab
    * If you want to contribute translation is happening on https://crowdin.com/project/jupyterlab

## Agenda Items

* **Navinn** would like to present the work done by the [MLH Fellowship](https://fellowship.mlh.io/) on the JupyterLab Git Extension.
* **Mike** will introduce early version of [JupyterLab citation manager extension](https://github.com/krassowski/jupyterlab-citation-manager)
* **David** would like to present the latest development in [akernel](https://github.com/davidbrochart/akernel): reactivity.
* **Tony** would like to share [jupyterlab-markup](https://github.com/agoose77/jupyterlab-markup) and [pidgy](https://github.com/deathbeds/pidgy).

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- [Voila on hackernews!](https://news.ycombinator.com/item?id=28364923)
- Some updates on JupyterLab translation based on new strings. Join us in translating on [crowdin](https://crowdin.com/project/jupyterlab)!

## Attendees

|   Name   |           Institution     | GitHub Handle                     |
|----------|---------------------------|-----------------------------------| 
| Frederic Collonval | QuantStack | @fcollonval |
| David Brochart | QuantStack | @davidbrochart |
| Thorin Tabor         | UCSD            | @tmtabor |
| Rick Wagner         | UCSD           | @rpwagner|
| Hamilton Ulmer| Mozilla | @hamilton | 
| Rollin Thomas         | NERSC            | @rcthomas | 
| Navinn Ravindaran | MLH Fellowship | @navn-r
| Luciano Resende | IBM | @lresende |
| Nick Bollweg | Georgia Tech | @bollwyvl @nrbgt 
| Loïc Huder | ESRF | @loichuder |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |
| Michał Krassowski | U Oxford | @krassowski |
| Jessica Xu | Quansight | @jess-x |

Plus 7 others.